@@ -23,6 +23,8 @@ type ResourceNames struct {
 	TektonDashboard string
 	TektonAddon     string
 	TektonConfig    string
+	TektonResult    string
+	TektonChain     string
 	Namespace       string
 	TargetNamespace string
 }
